@@ -1,10 +1,18 @@
 
 
-print.RFratiotest <- function(x, ...) {
-  if (is.null(x$model1.df) && is.null(x$loglik)) print.default(t(as.matrix(x)))#
-  else {
-    cat("\nApprox. likelihood ratio test\n")
-    cat("=============================\n")
+print.RFratiotest <- function(x, ...) {  
+  if (!is.null(x$simu.ratios)) {
+    ## MC ratio test
+     cat("\nMonte Carlo likelihood ratio test",
+         "\n=================================",
+         "\nnull model:", rfConvertRMmodel2string(x$model.list$nullmodel), 
+         "\nalt. model:", rfConvertRMmodel2string(x$model.list$alternative),
+         "\n",x$msg)
+ # } else if (is.null(x$model1.df) && is.null(x$loglik)) {
+#    ## wann wird diese if-Anweiung verwendet?
+ #     print.default(t(as.matrix(x)))
+  } else {
+    cat("\nApprox. likelihood ratio test\n=============================\n")
     if (is.null(x$model1.df)) {
       cat("null model: df=", x$df[1], "  loglik=", x$loglik[1], "\n", sep="")
       cat("alt. model: df=", x$df[2], "  loglik=", x$loglik[2], "\n", sep="")
@@ -58,20 +66,20 @@ mess <- function(alpha, p, df, nullmodelname=0, altmodelname=1:length(df)) {
 approx_test <- function(modellist, alpha) {
   n <- length(modellist)
   loglik <- df <- numeric()
+  
   for (m in 1:n) {
     if (class(modellist[[m]]) == "RF_fit") {
       df[m] <- modellist[[m]]$number.of.parameters
       loglik[m] <- modellist[[m]]$ml$ml.value
-    } else {
+    } else if (class(modellist[[m]]) == "RFfit") {
       df[m] <- modellist[[m]]@number.of.parameters
       loglik[m] <- modellist[[m]]["ml"]@likelihood
-    }
+    } else stop("wrong class ('", class(modellist), "') in approx_test.")
   }
   if (length(df) > 2 && (!missing(alpha) || length(alpha) > 1))
     stop("'alpha' must be a scalar")
   p <- pchisq(diff(loglik),  diff(df), lower.tail = FALSE)   
   txt <- mess(alpha=alpha, p=p, df=diff(df))
-  cat(txt)
   return(invisible(list(df=df, loglik=loglik, p=p, txt=txt)))
 }
 
@@ -260,12 +268,12 @@ approx_test_single <- function(model, method, alpha, modelinfo) {
 
 RFratiotest <-
   function(nullmodel, alternative,
-           x, y=NULL, z=NULL, T=NULL,  grid, data,
+           x, y=NULL, z=NULL, T=NULL,  grid=NULL, data,
            alpha,
            n = 5 / alpha, ## number of simulations to do
            seed = 0,
            lower=NULL, upper=NULL, 
-           BC.lambda, ## if missing then no BoxCox-Trafo
+           bc_lambda, ## if missing then no BoxCox-Trafo
            methods, # "reml", "rml1"),
            sub.methods,
            ## "internal" : name should not be changed; should always be last
@@ -310,11 +318,19 @@ RFratiotest <-
                    "delta.df", "p", "txt"
                    ), drop=FALSE]
       class(ats) <- "RFratiotest"
-      return(ats)
+      if (RFopt$general$returncall)
+        attr(ats, "call") <- as.character(deparse(match.call()))
+      attr(ats, "coord_system") <- c(orig=RFopt$coords$coord_system,
+                                     model=RFopt$coords$new_coord_system)
+    return(ats)
     } else {
       ats <- approx_test(list(nullmodel, alternative), alpha)
       class(ats) <- "RFratiotest"
-      return(ats)
+      if (RFopt$general$returncall)
+        attr(ats, "call") <- as.character(deparse(match.call()))
+      attr(ats, "coord_system") <- c(orig=RFopt$coords$coord_system,
+                                     model=RFopt$coords$new_coord_system)
+     return(ats)
     }
   } else if (missing(alternative) || (class(alternative) %in% classes))
     stop("alternative model is not given or not of model type")
@@ -322,7 +338,7 @@ RFratiotest <-
   
   if (!is.null(seed) && !is.na(seed)) set.seed(seed)
   else if (!is.na(RFopt$general$seed)) {
-    if (printlevel >= PL.IMPORPANT)
+    if (printlevel >= PL_IMPORTANT)
       message("NOTE: 'RFratiotest' is performed with fixed random seed ",
               RFopt$general$seed,
               ".\nSet RFoptions(seed=NA) to make the seed arbitrary.")
@@ -341,33 +357,39 @@ RFratiotest <-
   remove("Z")
 
   isSubmodel <- is.numeric(values) && all(is.na(values))
-  if (!isSubmodel && printlevel >= PL.IMPORPANT)
+  if (!isSubmodel && printlevel >= PL_IMPORTANT)
     message("'nullmodel' cannot be automatically detected as being a nullmodel of 'alternative'")
   
-  model.list <- list(nullmodel, alternative)
+  model.list <- list(nullmodel=nullmodel, alternative=alternative)
   data.fit <- list()
   guess <- users.guess
 
   for (m in 1:length(model.list)) {
     data.fit[[m]] <-
       RFfit(model.list[[m]], x=x, y=y, z=z, T=T, grid=grid, data=data,
-            lower=lower, upper=upper, BC.lambda=BC.lambda,
+            lower=lower, upper=upper, bc_lambda=bc_lambda,
              methods=methods,
             sub.methods=sub.methods, optim.control=optim.control,
             users.guess=guess,
             distances=distances, dim=dim,
             transform=transform,
-            ..., spConform = FALSE)$ml
-    guess <- if (isSubmodel) data.fit[[m]]$model else NULL
+            ..., spConform = FALSE)
+    guess <- if (isSubmodel) data.fit[[m]]$ml$model else NULL
   }
 
 
   if (RFopt$fit$ratiotest_approx) {
-    return(approx_test(data.fit))
+    ats <- approx_test(data.fit)
+    class(ats) <- "RFratiotest"
+    if (RFopt$general$returncall)
+      attr(ats, "call") <- as.character(deparse(match.call()))
+    attr(ats, "coord_system") <- c(orig=RFopt$coords$coord_system,
+                                   model=RFopt$coords$new_coord_system)
+   return(ats)
   }
   
-  model <- data.fit[[1]]$model
-  data.ratio <- -diff(sapply(data.fit, function(x) x$ml.value))
+  model <- data.fit[[1]]$ml$model
+  data.ratio <- -diff(sapply(data.fit, function(x) x$ml$ml.value))
   stopifnot(!isSubmodel || data.ratio <= 0) # should never appear
 
   simu.n <- n - 1
@@ -383,7 +405,7 @@ RFratiotest <-
   
   pch <- if (RFopt$general$pch=="") "" else '@'
   for (i in 1:simu.n) {
-    if (printlevel>=PL.SUBIMPORPANT)
+    if (printlevel>=PL_SUBIMPORTANT)
       cat("\n ", i, "th simulation out of", simu.n)
     else cat(pch)
     simu <- RFsimulate(model, x=newx, T=newT, grid=grid, 
@@ -393,7 +415,7 @@ RFratiotest <-
       simufit <-
         RFfit(model.list[[m]], x=newx, T=newT, grid=grid,
               data=simu,
-              lower=lower, upper=upper, BC.lambda=BC.lambda,
+              lower=lower, upper=upper, bc_lambda=bc_lambda,
               methods=methods,
               sub.methods=sub.methods, optim.control=optim.control,
               users.guess=guess,
@@ -408,7 +430,7 @@ RFratiotest <-
 
     stopifnot(!isSubmodel || ratio[i] <= 0)# should never appear
     
-    if (printlevel > PL.SUBIMPORPANT)
+    if (printlevel > PL_SUBIMPORTANT)
       Print(c(data.ratio, ratio), fit, rank(c(data.ratio, ratio))[1])#
   }
   
@@ -419,11 +441,14 @@ RFratiotest <-
   msg <-
     paste("\nThe likehood ratio test ranks the likelihood of the data on rank",
           r, "among", simu.n, "simulations:", mess(alpha=alpha, p=p))
-  
-  if (printlevel > 0) {
-    cat(msg)
-  }
-  invisible(list(p=p, n=n, data.ratio=data.ratio, simu.ratios=ratio,
-                 data.fit=data.fit, msg=msg)
-            )
+
+  res <- list(p=p, n=n, data.ratio=data.ratio, simu.ratios=ratio,
+              data.fit=data.fit, msg=msg, model.list=model.list)
+  class(res) <- "RFratiotest"
+  if (RFopt$general$returncall)
+    attr(res, "call") <- as.character(deparse(match.call()))
+  attr(res, "coord_system") <- c(orig=RFopt$coords$coord_system,
+                                 model=RFopt$coords$new_coord_system)
+  return(res)
+
 }
